@@ -4,6 +4,7 @@ import requests
 import threading
 from logging import getLogger
 from multiprocessing.pool import ThreadPool
+from time import sleep
 
 from eltyer.configuration.config import Config
 from eltyer.configuration import constants
@@ -15,6 +16,14 @@ from eltyer.exceptions import ClientException
 logger = getLogger(__name__)
 
 
+def notify_online_loop(api_key, algorithm_id, environment):
+
+    while True:
+        sleep(60)
+        url = f"{constants.ORCHESTRATION_ONLINE_ENDPOINT.format(algorithm_id=algorithm_id, environment=environment)}"
+        requests.get(url, headers={"x-api-key": api_key})
+
+
 class Client:
     config = Config()
     thread_count = 2
@@ -26,7 +35,7 @@ class Client:
     scheduler = None
     status = None
 
-    def start(self):
+    def start(self, notify_online=True):
 
         if not self.config.configured:
             raise ClientException("Client is not configured")
@@ -35,12 +44,21 @@ class Client:
         Client.algorithm_id = algorithm_data["algorithm_id"]
         Client.environment = algorithm_data["environment"]
 
-        self.create_subscription()
-        self.status = self.retrieve_subscription_status()
+        if notify_online:
+            self.create_subscription()
+            self.status = self.retrieve_subscription_status()
 
-        t = threading.Timer(60, self.notify_online)
-        t.daemon = True
-        t.start()
+            t = threading.Timer(
+                60,
+                notify_online_loop,
+                kwargs={
+                    "api_key": self.config.API_KEY,
+                    "algorithm_id": self.algorithm_id,
+                    "environment": self.environment
+                }
+            )
+            t.daemon = True
+            t.start()
 
     def create_subscription(self):
 
